@@ -1,12 +1,13 @@
 mod commands;
 mod core;
 
-use crate::commands::help;
-use crate::commands::projects;
-use crate::commands::version;
 use crate::core::cli::get_program_info;
 use crate::core::cli::CliCommand;
 use crate::core::config;
+use commands::all;
+use commands::help;
+use commands::projects;
+use commands::version;
 
 fn main() {
     config::init();
@@ -21,5 +22,6 @@ fn main() {
         CliCommand::Project => projects::check(program_info),
         CliCommand::Version => version::print_version(),
         CliCommand::Feature => projects::sync_feature(program_info),
+        CliCommand::All => all::run_git(program_info),
     }
 }
